@@ -10,7 +10,7 @@ account_id = os.getenv('ACCOUNT_ID') or '<put in your account id here>'
 
 
 class EURUSDListener(SynchronizationListener):
-    async def on_symbol_price_updated(self, price: MetatraderSymbolPrice):
+    async def on_symbol_price_updated(self, instance_index: int, price: MetatraderSymbolPrice):
         if price['symbol'] == 'EURUSD':
             print('EURUSD price updated', price)
 
@@ -22,7 +22,7 @@ async def stream_quotes():
 
         #  wait until account is deployed and connected to broker
         print('Deploying account')
-        await account.deploy()
+        #await account.deploy()
         print('Waiting for API server to connect to broker (may take couple of minutes)')
         await account.wait_connected()
 
